<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreUserRequest;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class AuthController extends Controller
{
    public function create(Request $request)
    {

        $rules = [
            'username' => 'required|unique:users',
            'password' => 'required'
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            return response()->json([
                'message' => $validator->messages()
            ], 400);
        }

        $username = $request->input('username');
        $password = $request->input('password');

        $newUser = new User();
        $newUser->username = $username;
        $newUser->token = '';
        $newUser->password = bcrypt($password);
        $newUser->save();

        return response()->json([
            'message' => 'Usuário Cadastrado com sucesso!'
        ], 200);
    }

    public function login(Request $request)
    {

        $creds = $request->only('username', 'password');

        $token = Auth::attempt($creds);



        if ($token) {
            return response()->json([
                'message' => 'Logado com sucesso',
                'token' => $token
            ], 200);
        } else {
            return response()->json([
                'message' => 'Usuário e/ou senha incorretos!',
            ], 400);
        }
    }

    public function logout()
    {
        Auth::logout();
        return response()->json([
            'message' => 'Você saiu do sistema!'
        ], 200);
    }

    public function me()
    {
        $user = Auth::user();

        return response()->json([
            'usuario' => $user->username
        ], 200);
    }
}
