<?php

namespace App\Http\Controllers;

use App\Http\Requests\SearchClienteRequest;
use App\Http\Requests\StoreClienteRequest;
use App\Http\Requests\UpdateClienteRequest;
use App\Http\Resources\ClienteResource;
use App\Models\Cliente;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Throwable;

class ClienteController extends Controller
{
    public function index(SearchClienteRequest $request)
    {
        $user = Auth::user();



        $search =  $request->input('search');

        if ($search) {
            $clientes = Cliente::where('user_id', $user->id)->where('NOME_FANTASIA', 'like', '%' . $search . '%')->orWhere('CNPJ', 'like', '%' . $search . '%')->get();
        } else {
            $clientes = Cliente::where('user_id', $user->id)->get();
        }

        return ClienteResource::collection($clientes);
    }

    public function store(StoreClienteRequest $request)
    {

        try {
            DB::beginTransaction();
            $user = Auth::user();

            $existsCnpj = Cliente::where('CNPJ', $request->input('CNPJ'))->first();

            if ($existsCnpj) {
                return response()->json([
                    'message' => 'Este CNPJ já está cadastrado no sistema!'
                ], 401);
            }

            $data = $request->validated();
            $data['user_id'] = $user->id;


            $cliente = Cliente::create($data);



            if ($data['lojas']) {
                foreach ($data['lojas'] as $key => $loja) {
                    if ($loja['CNPJ'] != '') {
                        $existsCnpj = Cliente::where('CNPJ', $loja['CNPJ'])->first();

                        if ($existsCnpj) {
                            DB::rollback();

                            return response()->json([
                                'message' => 'CNPJ ' . $loja['CNPJ'] . ' já está cadastrado no sistema!'
                            ], 401);
                        }
                        $lojaCreate = $loja;
                        $lojaCreate["cliente_id"] = $cliente->id;

                        $lojaCreate = array_merge($data, $lojaCreate);

                        Cliente::create($lojaCreate);
                    }
                }
            }
            DB::commit();

            return response()->json([
                'message' => 'Cliente cadastrado com sucesso!'
            ], 200);
        } catch (Throwable $e) {

            return response()->json([
                'message' => 'Ocorreu um erro ao salvar o cliente: ' . $e->getMessage()
            ], 400);
            DB::rollback();
        }
    }

    public function show($id)
    {
        $user = Auth::user();
        $cliente = Cliente::where('user_id', $user->id)->findOrFail($id);

        $lojas = Cliente::where('cliente_id', $id)->get();
        $cliente['lojas'] = $lojas;

        return $cliente;
    }

    public function update(UpdateClienteRequest $request, $id)
    {

        try {
            DB::beginTransaction();
            $user = Auth::user();
            $data = $request->validated();
            $cliente = Cliente::findOrFail($id);

            $existsCnpj = Cliente::where('CNPJ', $data['CNPJ'])->where('id', '!=', $cliente->id)->first();
            if ($existsCnpj) {
                return response()->json([
                    'message' => 'Já existe um cliente com o CNPJ informado!'
                ], 401);
            }

            if ($data['lojas']) {
                foreach ($data['lojas'] as $key => $loja) {
                    if ($loja['CNPJ'] != '') {
                        $existsCnpj = Cliente::where('CNPJ', $loja['CNPJ'])->where('cliente_id', '!=', $cliente->id)->first();

                        if ($existsCnpj) {
                            DB::rollback();

                            return response()->json([
                                'message' => 'CNPJ ' . $loja['CNPJ'] . ' já está cadastrado no sistema!'
                            ], 401);
                        }

                        $existsCnpjFilho = Cliente::where('CNPJ', $loja['CNPJ'])->where('cliente_id', '=', $cliente->id)->first();

                        if ($existsCnpjFilho) {
                            $existsCnpjFilho->update($loja);
                        } else {
                            $lojaCreate = $loja;
                            $lojaCreate['user_id'] = $user->id;
                            $lojaCreate["cliente_id"] = $cliente->id;

                            $lojaCreate = array_merge($data, $lojaCreate);

                            Cliente::create($lojaCreate);
                        }
                    }
                }
            }

            $cliente->update($data);
            DB::commit();

            return response()->json([
                'message' => 'Cliente atualizado com sucesso!'
            ], 200);
        } catch (Throwable $e) {

            return response()->json([
                'message' => 'Ocorreu um erro ao salvar o cliente: ' . $e->getMessage()
            ], 400);
            DB::rollback();
        }
    }

    public function destroy($id)
    {
        $cliente = Cliente::findOrFail($id);

        $cliente->delete();

        return response()->json([
            'message' => 'Cliente deletado com sucesso!'
        ], 200);
    }
}
