<?php
namespace App\Http\Controllers;

use App\Http\Requests\StoreFornecedorRequest;
use App\Http\Requests\UpdateFornecedorRequest;
use App\Http\Resources\FornecedorResource;
use App\Models\Fornecedor;
use Illuminate\Support\Facades\Auth;

class FornecedorController extends Controller
{
    public function index()
    {
        $user = Auth::user();
        $fornecedores = Fornecedor::where('user_id', $user->id)->get();

        return FornecedorResource::collection($fornecedores);
    }

    public function store(StoreFornecedorRequest $request)
    {
        $user = Auth::user();

        $existsCnpj = Fornecedor::where('CNPJ', $request->input('CNPJ'))->first();

        if ($existsCnpj) {
            return response()->json([
                'message' => 'Este CNPJ já está cadastrado no sistema!'
            ], 401);
        }

        $data = $request->validated();
        $data['user_id'] = $user->id;

        Fornecedor::create($data);

        return response()->json([
            'message' => 'Fornecedor cadastrado com sucesso!'
        ], 200);
    }

    public function show($id)
    {
        $user = Auth::user();
        $fornecedor = Fornecedor::where('user_id', $user->id)->findOrFail($id);

        return $fornecedor;
    }

    public function update(UpdateFornecedorRequest $request, $id)
    {
        $user = Auth::user();
        $data = $request->validated();

        $fornecedor = Fornecedor::where('user_id', $user->id)
            ->where('id', $id)
            ->firstOrFail();

        $existsCnpj = Fornecedor::where('CNPJ', $data['CNPJ'])
            ->where('id', '!=', $fornecedor->id)
            ->first();

        if ($existsCnpj) {
            return response()->json([
                'message' => 'Já existe um fornecedor com o CNPJ informado!'
            ], 401);
        }

        $fornecedor->update($data);

        return response()->json([
            'message' => 'Fornecedor atualizado com sucesso!'
        ], 200);
    }

    public function destroy($id)
    {
        $user = Auth::user();

        $fornecedor = Fornecedor::where('user_id', $user->id)
            ->findOrFail($id);

        $fornecedor->delete();

        return response()->json([
            'message' => 'Fornecedor deletado com sucesso!'
        ], 200);
    }
}
