<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreProdutoRequest;
use App\Http\Resources\ProdutoResource;
use App\Models\DescontosProduto;
use App\Models\Modulo;
use App\Models\Produto;
use App\Models\ProdutosPrecosPdv;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ProdutoController extends Controller
{
    public function index()
    {
        $user = Auth::user();
        $data = [];
        $produtos = Produto::with('fornecedor')
            ->where('user_id', $user->id)
            ->get();

        $data['data'] =  $produtos;
        return   $data;
    }

    public function store(StoreProdutoRequest $request)
    {
        $data = $request->validated();

        $user = Auth::user();

        $produtoData = [
            'user_id' => $user->id,
            'NOME' => $data['NOME'],
            'FORNECEDOR_ID' => $data['FORNECEDOR_ID'],
            'TIPO_VALOR' => $data['TIPO_VALOR'],
            'EXIBE_PEDIDO' => $data['EXIBE_PEDIDO'],
            'VALOR_TABELA' => $data['VALOR_TABELA'],
            'VALOR_MINIMO' => $data['VALOR_MINIMO'],
            'VALOR_IMPLANTACAO' => $data['VALOR_IMPLANTACAO'],
            'OBSERVACAO' => $data['OBSERVACAO'],
            'TIPO_DESCONTO' => $data['TIPO_DESCONTO'],
            'VALOR_DESCONTO_MAXIMO'  => $data['VALOR_DESCONTO_MAXIMO']
        ];

        $produto = Produto::create($produtoData);


        foreach ($data['modulos'] as $key => $modulo) {

            if ($modulo['VALOR'] != '')
                $modulo = Modulo::create([
                    'VALOR' => $modulo['VALOR'],
                    'MODULO' => $modulo['MODULO'],
                    'PRODUTO_ID' => $produto->id
                ]);
        }


        if ($data['TIPO_VALOR'] === 'composto') {
            foreach ($data['descontos'] as $key => $desconto) {

                if ($desconto['VALOR_PORCENTAGEM'] != '')
                    $desconto = DescontosProduto::create([
                        'QTD_INICIAL' => $desconto['QTD_INICIAL'],
                        'QTD_FINAL' => $desconto['QTD_FINAL'],
                        'VALOR_PORCENTAGEM' => $desconto['VALOR_PORCENTAGEM'],
                        'PRODUTO_ID' => $produto->id
                    ]);
            }
        }

        if ($data['TIPO_VALOR'] === 'pdv') {
            foreach ($data['precos_pdv'] as $key => $precos) {

                if ($precos['VALOR_MINIMO'] != '')
                    $preco = ProdutosPrecosPdv::create([
                        'QTD_INICIAL' => $precos['QTD_INICIAL'],
                        'QTD_FINAL' => $precos['QTD_FINAL'],
                        'VALOR_MINIMO' => $precos['VALOR_MINIMO'],
                        'VALOR_TABELA' => $precos['VALOR_TABELA'],
                        'VALOR_IMPLANTACAO' => $precos['VALOR_IMPLANTACAO'],
                        'PRODUTO_ID' => $produto->id
                    ]);
            }
        }


        return response()->json([
            'message' => 'Produto cadastrado com sucesso!'
        ], 200);
    }

    public function show($id)
    {
        $user = Auth::user();

        $produto = Produto::where('user_id', $user->id)->findOrFail($id);
        $modulos = $produto->modulos;
        $descontos = $produto->descontos;
        $precos = $produto->precos_pdv;



        return $produto;
    }


    public function update(Request $request, $id)
    {
        $user = Auth::user();

        $produto = Produto::where('user_id', $user->id)
            ->findOrFail($id);
        $data = $request->all();

        $produto->fill($data)->save();

        if (isset($data['modulos'])) {


            foreach ($data['modulos'] as $modulo) {

                $modoExists =  Modulo::find($modulo['id']);

                if ($modoExists) {
                    $modoExists->fill($modulo)->save();
                } else {
                    $modulo = Modulo::create([
                        'VALOR' => $modulo['VALOR'],
                        'MODULO' => $modulo['MODULO'],
                        'PRODUTO_ID' => $produto->id
                    ]);
                }
            }
        }
        if (isset($data['descontos'])) {
            DescontosProduto::where('PRODUTO_ID',  $produto->id)->delete();

            foreach ($data['descontos'] as $key => $desconto) {

                if ($desconto['VALOR_PORCENTAGEM'] != '')
                    $desconto = DescontosProduto::create([
                        'QTD_INICIAL' => $desconto['QTD_INICIAL'],
                        'QTD_FINAL' => $desconto['QTD_FINAL'],
                        'VALOR_PORCENTAGEM' => $desconto['VALOR_PORCENTAGEM'],
                        'PRODUTO_ID' => $produto->id
                    ]);
            }
        }

        if (isset($data['precos_pdv'])) {
            if ($data['TIPO_VALOR'] === 'pdv') {

                ProdutosPrecosPdv::where('PRODUTO_ID',  $produto->id)->delete();

                #sfsf
                foreach ($data['precos_pdv'] as $key => $precos) {

                    if ($precos['VALOR_MINIMO'] != '')
                        $preco = ProdutosPrecosPdv::create([
                            'QTD_INICIAL' => $precos['QTD_INICIAL'],
                            'QTD_FINAL' => $precos['QTD_FINAL'],
                            'VALOR_MINIMO' => $precos['VALOR_MINIMO'],
                            'VALOR_TABELA' => $precos['VALOR_TABELA'],
                            'VALOR_IMPLANTACAO' => $precos['VALOR_IMPLANTACAO'],
                            'PRODUTO_ID' => $produto->id
                        ]);
                }
            }
        }



        if ($data['TIPO_VALOR'] === 'composto') {
            DescontosProduto::where('PRODUTO_ID',  $produto->id)->delete();

            foreach ($data['descontos'] as $key => $desconto) {

                if ($desconto['VALOR_PORCENTAGEM'] != '')
                    $desconto = DescontosProduto::create([
                        'QTD_INICIAL' => $desconto['QTD_INICIAL'],
                        'QTD_FINAL' => $desconto['QTD_FINAL'],
                        'VALOR_PORCENTAGEM' => $desconto['VALOR_PORCENTAGEM'],
                        'PRODUTO_ID' => $produto->id
                    ]);
            }
        }

        if ($data['TIPO_VALOR'] === 'pdv') {
            ProdutosPrecosPdv::where('PRODUTO_ID',  $produto->id)->delete();
            foreach ($data['precos_pdv'] as $key => $precos) {

                if ($precos['VALOR_MINIMO'] != '')
                    $preco = ProdutosPrecosPdv::create([
                        'QTD_INICIAL' => $precos['QTD_INICIAL'],
                        'QTD_FINAL' => $precos['QTD_FINAL'],
                        'VALOR_MINIMO' => $precos['VALOR_MINIMO'],
                        'VALOR_TABELA' => $precos['VALOR_TABELA'],
                        'VALOR_IMPLANTACAO' => $precos['VALOR_IMPLANTACAO'],
                        'PRODUTO_ID' => $produto->id
                    ]);
            }
        }

        return response()->json([
            'message' => 'Produto atualizado com sucesso!'
        ], 200);
    }

    public function destroy($id)
    {
        $user = Auth::user();

        $produto = Produto::where('user_id', $user->id)
            ->findOrFail($id);

        $produto->delete();

        return response()->json([
            'message' => 'Produto deletado com sucesso!'
        ], 200);
    }
}
